@@ -113,6 +113,9 @@ function init_local_neutron_variables {
         OVS_BRIDGE_MAPPINGS=$vlan_mapping,$ext_mapping
 
     fi
+    if [ "$TRICIRCLE_ENABLE_TRUNK" == "True" ]; then
+        _neutron_service_plugin_class_add trunk
+    fi
 }
 
 function add_default_bridges {
@@ -279,23 +282,43 @@ function start_central_neutron_server {
     iniset $NEUTRON_CONF.$server_index client auto_refresh_endpoint True
     iniset $NEUTRON_CONF.$server_index client top_region_name $CENTRAL_REGION_NAME
 
-    local type_drivers=local
-    local tenant_network_types=local
-    if [ "$Q_ML2_PLUGIN_VLAN_TYPE_OPTIONS" != "" ]; then
-        type_drivers+=,vlan
-        tenant_network_types+=,vlan
-        iniset $NEUTRON_CONF.$server_index tricircle network_vlan_ranges `echo $Q_ML2_PLUGIN_VLAN_TYPE_OPTIONS | awk -F= '{print $2}'`
+    local service_plugins=''
+    if [ "$TRICIRCLE_ENABLE_TRUNK" == "True" ]; then
+        service_plugins+=",tricircle.network.central_trunk_plugin.TricircleTrunkPlugin"
     fi
+    if [ "$TRICIRCLE_ENABLE_SFC" == "True" ]; then
+        service_plugins+=",networking_sfc.services.flowclassifier.plugin.FlowClassifierPlugin,tricircle.network.central_sfc_plugin.TricircleSfcPlugin"
+        iniset $NEUTRON_CONF.$server_index sfc drivers tricircle_sfc
+        iniset $NEUTRON_CONF.$server_index flowclassifier drivers tricircle_fc
+    fi
+    if [ -n service_plugins ]; then
+        service_plugins=$(echo $service_plugins| sed 's/^,//')
+        iniset $NEUTRON_CONF.$server_index DEFAULT service_plugins "$service_plugins"
+    fi
+
+    local type_drivers=''
+    local tenant_network_types=''
     if [ "$Q_ML2_PLUGIN_VXLAN_TYPE_OPTIONS" != "" ]; then
         type_drivers+=,vxlan
         tenant_network_types+=,vxlan
         iniset $NEUTRON_CONF.$server_index tricircle vni_ranges `echo $Q_ML2_PLUGIN_VXLAN_TYPE_OPTIONS | awk -F= '{print $2}'`
     fi
+    if [ "$Q_ML2_PLUGIN_VLAN_TYPE_OPTIONS" != "" ]; then
+        type_drivers+=,vlan
+        tenant_network_types+=,vlan
+        iniset $NEUTRON_CONF.$server_index tricircle network_vlan_ranges `echo $Q_ML2_PLUGIN_VLAN_TYPE_OPTIONS | awk -F= '{print $2}'`
+    fi
     if [ "Q_ML2_PLUGIN_FLAT_TYPE_OPTIONS" != "" ]; then
         type_drivers+=,flat
         tenant_network_types+=,flat
         iniset $NEUTRON_CONF.$server_index tricircle flat_networks `echo $Q_ML2_PLUGIN_FLAT_TYPE_OPTIONS | awk -F= '{print $2}'`
     fi
+    type_drivers+=,local
+    tenant_network_types+=,local
+    # remove the heading ","
+    type_drivers=$(echo $type_drivers | sed 's/^,//')
+    tenant_network_types=$(echo $tenant_network_types | sed 's/^,//')
+
     iniset $NEUTRON_CONF.$server_index tricircle type_drivers $type_drivers
     iniset $NEUTRON_CONF.$server_index tricircle tenant_network_types $tenant_network_types
     iniset $NEUTRON_CONF.$server_index tricircle enable_api_gateway False
